@@ -15,27 +15,32 @@ R"""
 The main package `refinery` exports all `refinery.units.Unit`s which are also
 of type `refinery.units.Entry`, i.e. they expose a shell command. The command
 line interface for each of these units is given below, this is the same text
-as would be available by executing the command with the `-h` or `--help`
-option. To better understand how the command line parameters are parsed, it is
+as would be available by executing the command with the `-h` or `--help` option.
+The documentation for this module only lists the classes that correspond to
+exported refinery units, but for convenience, the `refinery` module also exports
+the classes `refinery.units.Unit` and `refinery.units.Arg`.
+
+To better understand how the command line parameters are parsed, it is also
 recommended to study the module documentation of the following library modules,
-as their content is relevant for command line use of the `refinery`.
+as their content is relevant for how the various `refinery.units.Unit`s can be
+combined.
 
-1. `refinery.lib.frame`
-2. `refinery.lib.argformats`
-3. `refinery.lib.meta`
-
-Furthermore, the module documentation of `refinery.units` contains a brief
-example of how to write simple units.
+1. `refinery.lib.frame`: framing syntax for working on lists of binary chunks
+2. `refinery.lib.argformats`: the multibin syntax for refinery arguments
+3. `refinery.lib.meta`: defining and using metadata variables within frames
+4. `refinery.units`: writing custom units, add command-line arguments, and how
+   to use refinery units within Python code.
 """
-__version__ = '0.4.28'
+__version__ = '0.4.29'
 __distribution__ = 'binary-refinery'
 
 from typing import Dict, Type
 from importlib import resources
+from datetime import datetime
 
 import pickle
 
-from refinery.units import arg, Unit
+from refinery.units import Arg, Unit
 
 
 def _singleton(cls):
@@ -67,6 +72,7 @@ class _cache:
         self.loaded = False
         self.units = {}
         self.cache = {}
+        self.last_reload = datetime(1985, 8, 5)
         self.load()
 
     def load(self):
@@ -102,8 +108,13 @@ class _cache:
 
     def _resolve(self, name, retry=0):
         if retry > 2:
-            raise AttributeError
+            raise AttributeError(name)
         elif retry >= 2:
+            now = datetime.utcnow()
+            delta = now - self.last_reload
+            if delta.total_seconds() < 10:
+                raise AttributeError(name)
+            self.last_reload = now
             self.reload()
         elif retry >= 1:
             self.load()
@@ -145,6 +156,7 @@ class __pdoc__(dict):
             return
         from .explore import get_help_string
         self['Unit'] = False
+        self['Arg'] = False
         for name in _cache.units:
             unit = _cache[name]
             for base in unit.mro():
@@ -172,21 +184,8 @@ class __pdoc__(dict):
         return super().items()
 
 
-def drain(stream):
-    """
-    A function wrapper around the `bytearray` data type. Can be used as the final sink in
-    a refinery pipeline in Python code, i.e.:
-
-        from refinery import *
-        # ...
-        output = data | carve('b64', single=True) | b64 | zl | drain
-        assert isinstance(output, bytearray)
-    """
-    return bytearray(stream)
-
-
-__all__ = [x for x, _ in sorted(_cache.units.items(), key=lambda x: x[1])] + [
-    Unit.__name__, arg.__name__, '__pdoc__', 'drain', 'UNIT_CACHE_PATH']
+__all__ = sorted(_cache.units, key=lambda x: x.lower()) + [
+    Unit.__name__, Arg.__name__, '__pdoc__', 'UNIT_CACHE_PATH']
 
 
 def __getattr__(name):
