@@ -24,11 +24,11 @@ If you want your custom refinery unit to accept command line parameters, you can
 write an initialization routine. For example, the following unit implements a
 very simple XOR unit (less versatile than the already existing `refinery.xor`):
 
-    from refinery import Unit, arg
+    from refinery import Unit
     import itertools
 
     class myxor (Unit):
-        def __init__(self, key: arg(help='Encryption key')):
+        def __init__(self, key: Unit.Arg.Binary(help='Encryption key')):
             pass
 
         def process(self, data: bytearray):
@@ -37,13 +37,15 @@ very simple XOR unit (less versatile than the already existing `refinery.xor`):
                 data[k] ^= next(key)
             return data
 
-The `refinery.arg` decorator is optional and only used here to provide a help
-message on the command line. The example also shows that the `__init__` code can
-be left empty: In this case, refinery automatically adds boilerplate code that
-copies all `__init__` parameters to the `args` member variable of the unit. In
-this case, the constructor will be completed to have the following code:
+The `refinery.Arg` decorator is optional and only used here to provide a help
+message on the command line. It is also available as the `Arg` class property
+of the `refinery.Unit` class for convenience. The example also shows that the
+`__init__` code can be left empty: In this case, refinery automatically adds
+boilerplate code that copies all `__init__` parameters to the `args` member
+variable of the unit. In this case, the constructor will be completed to have
+the following code:
 
-        def __init__(self, key: arg(help='Encryption key')):
+        def __init__(self, key: Unit.Arg.Binary(help='Encryption key')):
             super().__init__(key=key)
 
 The option of writing an empty `__init__` was added because it is rarely needed
@@ -193,7 +195,7 @@ from argparse import (
     ZERO_OR_MORE
 )
 
-from refinery.lib.argformats import pending, manifest, multibin, number, sliceobj, VariableMissing
+from refinery.lib.argformats import pending, manifest, multibin, numseq, number, sliceobj, VariableMissing
 from refinery.lib.argparser import ArgumentParserWithKeywordHooks, ArgparseError
 from refinery.lib.tools import documentation, isstream, lookahead, autoinvoke, one, skipfirst, isbuffer
 from refinery.lib.frame import Framed, Chunk
@@ -277,22 +279,23 @@ class Argument:
         return ', '.join(arglist)
 
 
-class arg(Argument):
+class Arg(Argument):
     """
-    This child class of `refinery.units.Argument` is specifically an argument for the
-    `add_argument` method of an `ArgumentParser` from the `argparse` module. It can also
-    be used as a decorator for the constructor of a refinery unit to better control
-    the argument parser of that unit's command line interface. Example:
+    This class is specifically an argument for the `add_argument` method of an `ArgumentParser` from
+    the `argparse` module. It can also be used as a decorator or annotation for the constructor of a
+    refinery unit to better control the argument parser of that unit's command line interface.
+    Example:
     ```
     class prefixer(Unit):
-        @arg('prefix', help='this data will be prepended to the input.')
-        def __init__(self, prefix): pass
-
+        def __init__(
+            self,
+            prefix: Arg.Binary(help='This data will be prepended to the input.')
+        ): ...
         def process(self, data):
             return self.args.prefix + data
     ```
-    Note that when the init of a unit has a return annotation that is a base class of
-    itself, then all its parameters will automatically be forwarded to that base class.
+    Note that when the init of a unit has a return annotation that is a base class of itself, then
+    all its parameters will automatically be forwarded to that base class.
     """
 
     class delete: pass
@@ -315,7 +318,7 @@ class arg(Argument):
     ) -> None:
         kwargs = dict(action=action, choices=choices, const=const, default=default, dest=dest,
             help=help, metavar=metavar, nargs=nargs, required=required, type=type)
-        kwargs = {key: value for key, value in kwargs.items() if value is not arg.omit}
+        kwargs = {key: value for key, value in kwargs.items() if value is not Arg.omit}
         self.group = group
         self.guessed = set(guessed or ())
         super().__init__(*args, **kwargs)
@@ -351,7 +354,7 @@ class arg(Argument):
         return super().__rmatmul__(method)
 
     @staticmethod
-    def as_option(value: Optional[Any], cls: Enum) -> Enum:
+    def AsOption(value: Optional[Any], cls: Enum) -> Enum:
         if value is None or isinstance(value, cls):
             return value
         if isinstance(value, str):
@@ -367,68 +370,87 @@ class arg(Argument):
             choices = ', '.join(cls)
             raise ValueError(F'Could not transform {value} into {cls.__name__}; the choices are: {choices}') from E
 
-    @staticmethod
-    def switch(
+    @classmethod
+    def Switch(
+        cls,
         *args   : str, off=False,
         help    : Union[omit, str] = omit,
         dest    : Union[omit, str] = omit,
         group   : Optional[str] = None,
-    ) -> Argument:
+    ):
         """
         A convenience method to add argparse arguments that change a boolean value from True to False or
         vice versa. By default, a switch will have a False default and change it to True when specified.
         """
-        return arg(*args, group=group, help=help, dest=dest, action='store_false' if off else 'store_true')
+        return cls(*args, group=group, help=help, dest=dest, action='store_false' if off else 'store_true')
 
-    @staticmethod
-    def binary(
+    @classmethod
+    def Binary(
+        cls,
         *args   : str,
         help    : Union[omit, str] = omit,
         dest    : Union[omit, str] = omit,
         metavar : Optional[str] = None,
         group   : Optional[str] = None,
-    ) -> Argument:
+    ):
         """
         Used to add argparse arguments that contain binary data.
         """
-        return arg(*args, group=group, help=help, dest=dest, type=multibin, metavar=metavar or 'B')
+        return cls(*args, group=group, help=help, dest=dest, type=multibin, metavar=metavar or 'B')
 
-    @staticmethod
-    def number(
+    @classmethod
+    def NumSeq(
+        cls,
+        *args   : str,
+        help    : Union[omit, str] = omit,
+        dest    : Union[omit, str] = omit,
+        metavar : Optional[str] = None,
+        group   : Optional[str] = None,
+    ):
+        """
+        Used to add argparse arguments that contain a numeric sequence.
+        """
+        return cls(*args, group=group, help=help, dest=dest, type=numseq, metavar=metavar)
+
+    @classmethod
+    def Number(
+        cls,
         *args   : str,
         bound   : Union[omit, Tuple[int, int]] = omit,
         help    : Union[omit, str] = omit,
         dest    : Union[omit, str] = omit,
         metavar : Optional[str] = None,
         group   : Optional[str] = None,
-    ) -> Argument:
+    ):
         """
         Used to add argparse arguments that contain a number.
         """
         nt = number
-        if bound is not arg.omit:
+        if bound is not cls.omit:
             lower, upper = bound
             nt = nt[lower:upper]
-        return arg(*args, group=group, help=help, dest=dest, type=nt, metavar=metavar or 'N')
+        return cls(*args, group=group, help=help, dest=dest, type=nt, metavar=metavar or 'N')
 
-    @staticmethod
-    def option(
+    @classmethod
+    def Option(
+        cls,
         *args   : str,
         choices : Enum,
         help    : Union[omit, str] = omit,
         dest    : Union[omit, str] = omit,
         metavar : Optional[str] = None,
         group   : Optional[str] = None,
-    ) -> Argument:
+    ):
         """
         Used to add argparse arguments with a fixed set of options, based on an enumeration.
         """
         cnames = [c.name for c in choices]
         metavar = metavar or choices.__name__
-        return arg(*args, group=group, help=help, metavar=metavar, dest=dest, choices=cnames, type=str)
+        return cls(*args, group=group, help=help, metavar=metavar, dest=dest, choices=cnames, type=str)
 
-    @staticmethod
-    def choice(
+    @classmethod
+    def Choice(
+        cls,
         *args   : str,
         choices : List[str],
         help    : Union[omit, str] = omit,
@@ -441,7 +463,7 @@ class arg(Argument):
         """
         Used to add argparse arguments with a fixed set of options, based on a list of strings.
         """
-        return arg(*args, group=group, type=type, metavar=metavar, nargs=nargs,
+        return cls(*args, group=group, type=type, metavar=metavar, nargs=nargs,
             dest=dest, help=help, choices=choices)
 
     @property
@@ -467,7 +489,7 @@ class arg(Argument):
             raise AttributeError(F'The argument with these values has no destination: {self!r}')
 
     @classmethod
-    def infer(cls, pt: inspect.Parameter):
+    def Infer(cls, pt: inspect.Parameter):
         """
         This class method can be used to infer the argparse argument for a Python function
         parameter. This guess is based on the annotation, name, and default value.
@@ -508,7 +530,7 @@ class arg(Argument):
             except Exception: pass
 
         if annotation is not pt.empty:
-            if isinstance(annotation, arg):
+            if isinstance(annotation, Arg):
                 if annotation.kwargs.get('dest', pt.name) != pt.name:
                     raise ValueError(
                         F'Incompatible argument destination specified; parameter {pt.name} '
@@ -574,9 +596,9 @@ class arg(Argument):
         if not self.args:
             self.args = list(them.args)
 
-    def merge_all(self, them: arg) -> None:
+    def merge_all(self, them: Arg) -> None:
         for key, value in them.kwargs.items():
-            if value is arg.delete:
+            if value is Arg.delete:
                 self.kwargs.pop(key, None)
                 self.guessed.discard(key)
                 continue
@@ -599,12 +621,12 @@ class arg(Argument):
         return clone
 
     def __repr__(self) -> str:
-        return F'arg({super().__repr__()})'
+        return F'{self.__class__.__name__}({super().__repr__()})'
 
     def __call__(self, init: Callable) -> Callable:
         parameters = inspect.signature(init).parameters
         try:
-            inferred = arg.infer(parameters[self.destination])
+            inferred = Arg.Infer(parameters[self.destination])
             inferred.merge_all(self)
             init.__annotations__[self.destination] = inferred
         except KeyError:
@@ -617,7 +639,7 @@ class ArgumentSpecification(OrderedDict):
     A container object that stores `refinery.units.arg` specifications.
     """
 
-    def merge(self: Dict[str, arg], argument: arg):
+    def merge(self: Dict[str, Arg], argument: Arg):
         """
         Insert or update the specification with the given argument.
         """
@@ -692,11 +714,11 @@ class Executable(ABCMeta):
     for the other ones.
     """
 
-    _argument_specification: Dict[str, arg]
+    _argument_specification: Dict[str, Arg]
 
-    def _infer_argspec(cls, parameters: Dict[str, inspect.Parameter], args: Optional[Dict[str, arg]] = None):
+    def _infer_argspec(cls, parameters: Dict[str, inspect.Parameter], args: Optional[Dict[str, Arg]] = None):
 
-        args: Dict[str, arg] = ArgumentSpecification() if args is None else args
+        args: Dict[str, Arg] = ArgumentSpecification() if args is None else args
 
         exposed = [pt.name for pt in skipfirst(parameters.values()) if pt.kind != pt.VAR_KEYWORD]
         # The arguments are added in reverse order to the argument parser later.
@@ -705,7 +727,7 @@ class Executable(ABCMeta):
 
         for name in exposed:
             try:
-                argument = arg.infer(parameters[name])
+                argument = Arg.Infer(parameters[name])
             except KeyError:
                 continue
             args.merge(argument)
@@ -754,25 +776,38 @@ class Executable(ABCMeta):
 
     def __init__(cls, name: str, bases: Sequence[Executable], nmspc: Dict[str, Any], abstract=False):
         super(Executable, cls).__init__(name, bases, nmspc)
-        cls._argument_specification = ArgumentSpecification()
+        cls._argument_specification = args = ArgumentSpecification()
 
         cls_init = cls.__init__
         sig_init = inspect.signature(cls_init)
         parameters = sig_init.parameters
+        has_keyword = any(p.kind == p.VAR_KEYWORD for p in parameters.values())
+        inherited = []
 
         for base in bases:
             base: Executable
             for key, value in base._argument_specification.items():
                 if key in parameters:
-                    cls._argument_specification[key] = value.__copy__()
+                    args[key] = value.__copy__()
 
-        cls._infer_argspec(parameters, cls._argument_specification)
+        if not abstract and bases and has_keyword:
+            for key, value in bases[0]._argument_specification.items():
+                if key not in args:
+                    args[key] = value.__copy__()
+                    inherited.append(key)
 
-        if not abstract and any(p.kind == p.VAR_KEYWORD for p in parameters.values()):
+        cls._infer_argspec(parameters, args)
+
+        if not abstract and has_keyword:
             @wraps(cls.__init__)
-            def init(self, *args, **kwargs): super(cls, self).__init__(*args, **kwargs)
-            init.__signature__ = sig_init.replace(parameters=tuple(
-                p for p in parameters.values() if p.kind != p.VAR_KEYWORD))
+            def init(self, *args, **kwargs):
+                super(cls, self).__init__(*args, **kwargs)
+            params = [p for p in parameters.values() if p.kind != p.VAR_KEYWORD]
+            if inherited:
+                pp = inspect.signature(bases[0].__init__).parameters
+                for name in inherited:
+                    params.append(pp[name])
+            init.__signature__ = sig_init.replace(parameters=tuple(params))
             cls.__init__ = init
 
         try:
@@ -1065,7 +1100,7 @@ class Unit(UnitBase, abstract=True):
     implement the _framing_ syntax for producing multiple outputs and ingesting
     multiple inputs in a common format. For more details, see `refinery.lib.frame`.
     """
-    Arg = arg
+    Arg = Arg
 
     optional_dependencies: Optional[Set[str]] = None
     required_dependencies: Optional[Set[str]] = None
@@ -1160,10 +1195,15 @@ class Unit(UnitBase, abstract=True):
                 return exception.partial
             except AttributeError:
                 return data
-        if self.log_level >= LogLevel.DETACHED:
-            if isinstance(exception, RefineryPartialResult) and self.leniency > 0:
+        if isinstance(exception, RefineryPartialResult):
+            self.log_warn(F'error, partial result returned: {exception}')
+            if self.leniency >= 1:
+                return exception.partial
+            elif self.log_level < LogLevel.DETACHED:
                 return None
             raise exception
+        elif self.log_level >= LogLevel.DETACHED:
+            raise exception
         elif isinstance(exception, RefineryCriticalException):
             self.log_warn(F'critical error, terminating: {exception}')
             raise exception
@@ -1172,11 +1212,6 @@ class Unit(UnitBase, abstract=True):
             raise RefineryCriticalException
         elif isinstance(exception, GeneratorExit):
             raise exception
-        elif isinstance(exception, RefineryPartialResult):
-            self.log_warn(F'error, partial result returned: {exception}')
-            if self.leniency < 1:
-                return None
-            return exception.partial
         elif isinstance(exception, RefineryImportMissing):
             self.log_fail(F'dependencies missing; install {exception.install}')
         else:
