@@ -3,7 +3,7 @@
 import re
 from typing import Iterable
 
-from refinery.units.blockwise import arg, BlockTransformationBase
+from refinery.units.blockwise import Arg, BlockTransformationBase
 from refinery.units.encoding.base import base as BaseUnit
 from refinery.lib.argformats import number
 from refinery.lib.patterns import formats
@@ -21,12 +21,12 @@ class pack(BlockTransformationBase):
     """
 
     def __init__(self,
-        base: arg(type=number[2:36], help=(
+        base: Arg(type=number[2:36], help=(
             'Find only numbers in given base. Default of 0 means that '
             'common expressions for hexadecimal, octal and binary are '
             'accepted.')) = 0,
-        prefix  : arg.switch('-r', help='Add numeric prefixes like 0x, 0b, and 0o in reverse mode.') = False,
-        strict  : arg.switch('-s', help='Only parse integers that fit in one block of the given block size.') = False,
+        prefix  : Arg.Switch('-r', help='Add numeric prefixes like 0x, 0b, and 0o in reverse mode.') = False,
+        strict  : Arg.Switch('-s', help='Only parse integers that fit in one block of the given block size.') = False,
         bigendian=False, blocksize=1
     ):
         super().__init__(
